# coding: utf-8

"""
    Rapidata.Dataset

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from rapidata.api_client.models.datapoint_model_asset import DatapointModelAsset
from rapidata.api_client.models.get_validation_rapids_result_asset import GetValidationRapidsResultAsset
from typing import Optional, Set
from typing_extensions import Self

class SampleByIdentifier(BaseModel):
    """
    SampleByIdentifier
    """ # noqa: E501
    id: StrictStr
    identifier: StrictStr
    participant_id: StrictStr = Field(alias="participantId")
    participant_name: StrictStr = Field(alias="participantName")
    asset: DatapointModelAsset
    prompt: Optional[StrictStr] = None
    prompt_asset: Optional[GetValidationRapidsResultAsset] = Field(default=None, alias="promptAsset")
    tags: List[StrictStr]
    created_at: Optional[datetime] = Field(default=None, alias="createdAt")
    owner_id: Optional[StrictStr] = Field(default=None, alias="ownerId")
    owner_mail: StrictStr = Field(alias="ownerMail")
    __properties: ClassVar[List[str]] = ["id", "identifier", "participantId", "participantName", "asset", "prompt", "promptAsset", "tags", "createdAt", "ownerId", "ownerMail"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SampleByIdentifier from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of asset
        if self.asset:
            _dict['asset'] = self.asset.to_dict()
        # override the default output from pydantic by calling `to_dict()` of prompt_asset
        if self.prompt_asset:
            _dict['promptAsset'] = self.prompt_asset.to_dict()
        # set to None if prompt (nullable) is None
        # and model_fields_set contains the field
        if self.prompt is None and "prompt" in self.model_fields_set:
            _dict['prompt'] = None

        # set to None if prompt_asset (nullable) is None
        # and model_fields_set contains the field
        if self.prompt_asset is None and "prompt_asset" in self.model_fields_set:
            _dict['promptAsset'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SampleByIdentifier from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "identifier": obj.get("identifier"),
            "participantId": obj.get("participantId"),
            "participantName": obj.get("participantName"),
            "asset": DatapointModelAsset.from_dict(obj["asset"]) if obj.get("asset") is not None else None,
            "prompt": obj.get("prompt"),
            "promptAsset": GetValidationRapidsResultAsset.from_dict(obj["promptAsset"]) if obj.get("promptAsset") is not None else None,
            "tags": obj.get("tags"),
            "createdAt": obj.get("createdAt"),
            "ownerId": obj.get("ownerId"),
            "ownerMail": obj.get("ownerMail")
        })
        return _obj


